/************************************************
* LOOKUP - lookup table loader/saver			*
*												*
* 900226 MCMason - originally written			*
************************************************/

#include <stdio.h>
#include <io.h>

/***** luLoad - load the lookup table
*
* INP:	fname - the name of the lookup table to
*				be loaded.
*		buf   - the buffer to put the table into
*		elsiz - size (bytes) of data element
*		maxel - buffer size (# elements)
* OUT:	number of elements read if there is no error,
*		-1 if error in the file,
*		-2 if data type of table is incorrect
*		-3 if table is too large
*/
long luLoad(char *fname, void *buf, int elsiz,
		    long maxel)
	{
	FILE *inf;
	long TableSize;

	if (access(fname,00))
		return -1;		/* Can't access table	*/
	if ((inf=fopen(fname,"rb"))==NULL)
		return -1;		/* Can't open table		*/
	if (fread(&TableSize,sizeof(long),1,inf)!=1)
		return -1;		/* Can't read table size*/
	if (maxel < TableSize)
		return -3;		/* Table is too large	*/
	if (fread(buf,elsiz,TableSize,inf)!=TableSize)
		return -1;		/* Read error			*/
	if (fclose(inf))
		return -1;		/* Close error			*/
	else
		return TableSize;	/* Normal return	*/
	}

/***** luSave - save a lookup table
*
* INP:	fname - filespec to save table under
*		buf   - address of table
*		elsiz - table element size
*		numel - number of elements in the table
* OUT:	0 if the table is saved
*		-1 a file of that name already exists
*		-2 file open/close error
*		-3 file writing error
*/
int luSave(char *fname, void *buf, int elsiz,
			long numel)
	{
	FILE *outf;

/*	if (access(fname,0))
		return -1;		/* File exists			*/
	if ((outf=fopen(fname,"wb"))==NULL)
		return -2;		/* Can't open file		*/
	if (fwrite(&numel,sizeof(long),1,outf)!=1)
		return -3;		/* Can't write to file	*/
	if (fwrite(buf,elsiz,numel,outf) != numel)
		return -3;		/* Can't write to file	*/
	if (fclose(outf))
		return -2;		/* Can't close file		*/
	return 0;			/* Normal return		*/
	}

/***** luSize - get lookup table size (in bytes)
*
* INP:	fname - filespec holding lookup table
* OUT:	Positive: size (in bytes) of lookup table,
*		negative: error
*/
long luSize(char *fname)
	{
	FILE *inf;
	long TableSize;

	if (access(fname,00))
		return -1;		/* Can't access table	*/
	if ((inf=fopen(fname,"rb"))==NULL)
		return -1;		/* Can't open table		*/
	if (fread(&TableSize,sizeof(long),1,inf)!=1)
		return -1;		/* Can't read table size*/
	if (fclose(inf))
		return -1;		/* Close error			*/
	else
		return TableSize;	/* Normal return	*/
	}
