/************************************************
* TEST - test the timer library.  This program	*
* will simply time how long it takes to obtain	*
* the current time with the three methods that	*
* are described in the article.					*
************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <sys\timeb.h>
#include <bios.h>
/*#include <dos.h>*/
#include "timer.h"

double EmptyLoopTime=0.0;

void printResults(long a, long b, char *s)
	{
	printf("%s seconds for 1,000,000 invocations "
		   "of %s.\n",
		   tFormat(a,b),s);
	printf("This equals %lf s per call.\n\n",
			tDiff(a,b)-EmptyLoopTime);
	}

void main(void)
	{
	long	i, j, t1, t2;
	time_t	tx;
	struct  timeb tb;
	long far *TickCount=(long far *)0x0040006cL;

	/* How long does an empty loop take?		*/
	t1=tStart();
	for (j=0; j<1000000L; j++)
		;
	t2=tGet();
	printResults(t1,t2,"*** Empty Loop ***");
	EmptyLoopTime = tDiff(t1,t2);

	/* How long does it take to call 'time(x)'?	*/
	t1=tStart();
	for (j=0; j<1000000L; j++)
		time(&tx);
	t2=tGet();
	printResults(t1,t2,"time(&tx)");

	/* How long does it take to call 'ftime(x)?' */
	t1=tStart();
	for (j=0; j<1000000L; j++)
		ftime(&tb);
	t2=tGet();
	printResults(t1,t2,"ftime(&tb)");

	/* How long does it take to call 'clock()'? */
	t1=tStart();
	for (j=0; j<1000000L; j++)
		i=clock();
	t2=tGet();
	printResults(t1,t2,"clock()");

	/* How about 'biostime(x)'?					*/
	t1=tStart();
	for (j=0; j<1000000L; j++)
		i=_bios_timeofday(0,0L);
	t2=tGet();
	printResults(t1,t2,"biostime(0,0L)");

	/* How about our 'tGet()' function?			*/
	t1=tStart();
	for (j=0; j<1000000L; j++)
		i=tGet();
	t2=tGet();
	printResults(t1,t2,"tGet()");
	}
